import { Runtype } from './runtype';
export declare function getRecordFields(r: Runtype<any>): {
    [key: string]: Runtype<any>;
} | undefined;
/**
 * An object with defined keys and values.
 *
 * In contrast to typescript types, objects checked by this runtype will fail
 * if they have any additional keys (strict checking) not specified in
 * typemap.
 *
 * Keeps you save from unwanted propertiers and evil __proto__ injections.
 */
export declare function record<T extends object>(typemap: {
    [K in keyof T]: Runtype<T[K]>;
}): Runtype<T>;
/**
 * Like record but ignore unknown keys.
 *
 * Returns a new object that only contains the keys specified in the typemap.
 * Additional keys are ignored.
 *
 * Keeps you save from unwanted propertiers and evil __proto__ injections.
 */
export declare function sloppyRecord<T extends object>(typemap: {
    [K in keyof T]: Runtype<T[K]>;
}): Runtype<T>;
